<?php

declare(strict_types=1);

namespace Drupal\config_preview_deploy\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for Config Preview Deploy settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['config_preview_deploy.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'config_preview_deploy_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('config_preview_deploy.settings');

    $form['production_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Production Environment'),
      '#description' => $this->t('Configure the production environment where configurations will be deployed.'),
    ];

    $form['production_settings']['production_url'] = [
      '#type' => 'url',
      '#title' => $this->t('Production URL'),
      '#description' => $this->t('The base URL of the production environment (e.g., https://example.com).'),
      '#default_value' => $config->get('production_url'),
      '#required' => TRUE,
    ];

    $form['webhook_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Webhook Configuration'),
      '#description' => $this->t('Optional webhook settings for triggering preview environment rebuilds.'),
    ];

    $form['webhook_settings']['webhook_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable rebase webhook'),
      '#description' => $this->t('Enable webhook to trigger preview environment rebuilds when rebasing is needed.'),
      '#default_value' => $config->get('webhook.enabled'),
    ];

    $form['webhook_settings']['webhook_url'] = [
      '#type' => 'url',
      '#title' => $this->t('Rebase Webhook URL'),
      '#description' => $this->t('The URL to trigger when the preview environment needs to be rebuilt with production configuration.'),
      '#default_value' => $config->get('webhook.url'),
      '#states' => [
        'visible' => [
          ':input[name="webhook_enabled"]' => ['checked' => TRUE],
        ],
        'required' => [
          ':input[name="webhook_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('config_preview_deploy.settings')
      ->set('production_url', $form_state->getValue('production_url'))
      ->set('webhook.enabled', $form_state->getValue('webhook_enabled'))
      ->set('webhook.url', $form_state->getValue('webhook_url'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
